Generate eigenvalues of precision matrix Q on the surface of a sphere.
Source:R/eigenQsphere.R
eigenQsphere.RdThe eigenvalues of the precision matrix Q with dimension (mm, nn)
and polar angle limits phimin, phimax are calculated.
Value
A list containing 2 elements:
eigval Row vector containing the eigenvalues of Q.
eigvec Matrix containing the eigenvectors of Q as columns.
Details
The corresponding function for data on a grid is eigenLaplace.